==========
References
==========

.. [Betts2003] Betts, John T. and Huffman, William P. "Large Scale Parameter
   Estimation Using Sparse Nonlinear Programming Methods". SIAM J. Optim., Vol
   14, No. 1, pp. 223-244, 2003.
.. [Park2004] Park, S., Horak, F. B., & Kuo, A. D. (2004). Postural feedback
   responses scale with biomechanical constraints in human standing.
   Experimental Brain Research, 154(4), 417–427.
   https://doi.org/10.1007/s00221-003-1674-3
.. [Ackermann2010] Ackermann, M., & van den Bogert, A. J. (2010). Optimality
   principles for model-based prediction of human gait. Journal of
   Biomechanics, 43(6), 1055–1060.
   https://doi.org/10.1016/j.jbiomech.2009.12.012
.. [Betts2010] Betts, J. Practical Methods for Optimal Control and Estimation
   Using Nonlinear Programming. Advances in Design and Control. Society for
   Industrial and Applied Mathematics, 2010.
   https://doi.org/10.1137/1.9780898718577.
.. [Vyasarayani2011] Vyasarayani, Chandrika P., Thomas Uchida, Ashwin Carvalho,
   and John McPhee.  "Parameter Identification in Dynamic Systems Using the
   Homotopy Optimization Approach". Multibody System Dynamics 26, no. 4 (2011):
   411-24.
